function [ Sm_VM ] = VM_Stress_Mean(Kf_bend, Sm_bend, Kf_axial, Sm_axial, Kfs, Tm )
%
%  This routine computed the von Mises alternating fatigue stress.  It is
%  based on equation 6-55 in Shigley
%
%    Kf_bend = the fatigue stress concentration factor for bending
%    Sm_bend = the mean bending stress
%    Kf_axial = the fatique stress concentration factor for axial stress
%    Sm_axial = the mean axial stress
%    Kfs = the stress concentration factor for torsion
%    Tm = the mean torsion stress
%

Sm_VM = sqrt((Kf_bend*Sm_bend + Kf_axial*Sm_axial)^2 + 3*(Kfs*Tm)^2);

end

